@@ -25,7 +25,7 @@
 
 package PDF::Create;
 
-our $VERSION = "1.02";
+our $VERSION = "1.04";
 our $DEBUG   = 0;
 
 use strict;
@@ -90,7 +90,7 @@ sub new {
   $self->{'Keywords'} = $params{'Keywords'} if defined $params{'Keywords'};
   if (defined $params{'CreationDate'}) {
     $self->{'CreationDate'} =
-      sprintf "D:4u%0.2u%0.2u%0.2u%0.2u%0.2u",
+      sprintf "D:%4u%0.2u%0.2u%0.2u%0.2u%0.2u",
 	$params{'CreationDate'}->[5] + 1900, $params{'CreationDate'}->[4] + 1,
 	$params{'CreationDate'}->[3], $params{'CreationDate'}->[2],
 	$params{'CreationDate'}->[1], $params{'CreationDate'}->[0];
@@ -1208,6 +1208,8 @@ to the document if it is referenced at least once before the close method
 is called. In this version GIF, interlaced GIF and JPEG is supported. 
 Usage of interlaced GIFs are slower because they are decompressed, modified 
 and compressed again.
+The gif support is limited to images with a lwz min code size of 8. Small
+images with few colors can have a smaller min code size. 
 
 Parameters: 
 
